@@ -101,6 +101,9 @@ namespace libtorrent {
 	// .torrent file using bencode().
 	struct TORRENT_EXPORT create_torrent
 	{
+#if TORRENT_ABI_VERSION == 1
+		using flags_t = create_flags_t;
+#endif
 		// This will insert pad files to align the files to piece boundaries, for
 		// optimized disk-I/O. This will minimize the number of bytes of pad-
 		// files, to keep the impact down for clients that don't support
@@ -146,6 +149,14 @@ namespace libtorrent {
 		// be a multiple of 16 kiB. If a piece size of 0 is specified, a
 		// piece_size will be calculated such that the torrent file is roughly 40 kB.
 		//
+		// The file_storage (``fs``) parameter defines the files, sizes and
+		// their properties for the torrent to be created. Set this up first,
+		// before passing it to the create_torrent constructor.
+		//
+		// .. warning::
+		// 	The file_storage and torrent_info objects must stay alive for the
+		// 	entire duration of the create_torrent object.
+		//
 		// If a ``pad_file_limit`` is specified (other than -1), any file larger than
 		// the specified number of bytes will be preceded by a pad file to align it
 		// with the start of a piece. The pad_file_limit is ignored unless the
@@ -160,7 +171,7 @@ namespace libtorrent {
 		// have any affect.
 		//
 		// The ``flags`` arguments specifies options for the torrent creation. It can
-		// be any combination of the flags defined by create_torrent::flags_t.
+		// be any combination of the flags defined by create_flags_t.
 		//
 		// ``alignment`` is used when pad files are enabled. This is the size
 		// eligible files are aligned to. The default is -1, which means the
@@ -293,7 +304,7 @@ namespace libtorrent {
 
 	private:
 
-		file_storage& m_files;
+		file_storage const& m_files;
 		// if m_info_dict is initialized, it is
 		// used instead of m_files to generate
 		// the info dictionary
@@ -422,6 +433,7 @@ namespace detail {
 #endif
 
 #if TORRENT_ABI_VERSION == 1
+#if defined TORRENT_WINDOWS
 
 	// all wstring APIs are deprecated since 0.16.11
 	// instead, use the wchar -> utf8 conversion functions
@@ -467,6 +479,7 @@ namespace detail {
 	{
 		set_piece_hashes_deprecated(t, p, detail::nop, ec);
 	}
+#endif // TORRENT_WINDOWS
 #endif // TORRENT_ABI_VERSION
 
 namespace aux {
