@@ -73,6 +73,17 @@ using http_handler = std::function<void(error_code const&
 using http_connect_handler = std::function<void(http_connection&)>;
 
 using http_filter_handler = std::function<void(http_connection&, std::vector<tcp::endpoint>&)>;
+using hostname_filter_handler = std::function<bool(http_connection&, string_view)>;
+
+struct bind_info_t
+{
+	std::string device;
+	address ip;
+	bool operator==(bind_info_t const& rhs) const
+	{
+		return device == rhs.device && ip == rhs.ip;
+	}
+};
 
 // when bottled, the last two arguments to the handler
 // will always be 0
@@ -82,12 +93,13 @@ struct TORRENT_EXTRA_EXPORT http_connection
 	http_connection(io_service& ios
 		, resolver_interface& resolver
 		, http_handler const& handler
-		, bool bottled = true
-		, int max_bottled_buffer_size = default_max_bottled_buffer_size
-		, http_connect_handler const& ch = http_connect_handler()
-		, http_filter_handler const& fh = http_filter_handler()
+		, bool bottled
+		, int max_bottled_buffer_size
+		, http_connect_handler const& ch
+		, http_filter_handler const& fh
+		, hostname_filter_handler const& hfh
 #ifdef TORRENT_USE_OPENSSL
-		, ssl::context* ssl_ctx = nullptr
+		, ssl::context* ssl_ctx
 #endif
 		);
 
@@ -105,9 +117,9 @@ struct TORRENT_EXTRA_EXPORT http_connection
 	std::string m_sendbuffer;
 
 	void get(std::string const& url, time_duration timeout = seconds(30)
-		, int prio = 0, aux::proxy_settings const* ps = nullptr, int handle_redirects = 5
+		, aux::proxy_settings const* ps = nullptr, int handle_redirects = 5
 		, std::string const& user_agent = std::string()
-		, boost::optional<address> const& bind_addr = boost::optional<address>()
+		, boost::optional<bind_info_t> const& bind_addr = boost::none
 		, resolver_flags resolve_flags = resolver_flags{}, std::string const& auth_ = std::string()
 #if TORRENT_USE_I2P
 		, i2p_connection* i2p_conn = nullptr
@@ -115,9 +127,9 @@ struct TORRENT_EXTRA_EXPORT http_connection
 		);
 
 	void start(std::string const& hostname, int port
-		, time_duration timeout, int prio = 0, aux::proxy_settings const* ps = nullptr
+		, time_duration timeout, aux::proxy_settings const* ps = nullptr
 		, bool ssl = false, int handle_redirect = 5
-		, boost::optional<address> const& bind_addr = boost::optional<address>()
+		, boost::optional<bind_info_t> const& bind_addr = boost::none
 		, resolver_flags resolve_flags = resolver_flags{}
 #if TORRENT_USE_I2P
 		, i2p_connection* i2p_conn = nullptr
@@ -130,6 +142,8 @@ struct TORRENT_EXTRA_EXPORT http_connection
 
 	std::vector<tcp::endpoint> const& endpoints() const { return m_endpoints; }
 
+	std::string const& url() const { return m_url; }
+
 private:
 
 #if TORRENT_USE_I2P
@@ -137,8 +151,7 @@ private:
 	void on_i2p_resolve(error_code const& e
 		, char const* destination);
 #endif
-	void on_resolve(error_code const& e
-		, std::vector<address> const& addresses);
+	void on_resolve(error_code const& e, std::vector<address> const& addresses);
 	void connect();
 	void on_connect(error_code const& e);
 	void on_write(error_code const& e);
@@ -165,7 +178,6 @@ private:
 
 #ifdef TORRENT_USE_OPENSSL
 	ssl::context* m_ssl_ctx;
-	bool m_own_ssl_context;
 #endif
 
 #if TORRENT_USE_I2P
@@ -177,9 +189,9 @@ private:
 	http_handler m_handler;
 	http_connect_handler m_connect_handler;
 	http_filter_handler m_filter_handler;
+	hostname_filter_handler m_hostname_filter_handler;
 	deadline_timer m_timer;
 
-	time_duration m_read_timeout;
 	time_duration m_completion_timeout;
 
 	// the timer fires every 250 millisecond as long
@@ -193,8 +205,8 @@ private:
 	// configured to use a proxy
 	aux::proxy_settings m_proxy;
 
-	// the address to bind to. unset means do not bind
-	boost::optional<address> m_bind_addr;
+	// the address and/or device to bind to. unset means do not bind
+	boost::optional<bind_info_t> m_bind_addr;
 
 	// if username password was passed in, remember it in case we need to
 	// re-issue the request for a redirect
@@ -215,10 +227,6 @@ private:
 	// the number of bytes we are allowed to receive
 	int m_download_quota;
 
-	// the priority we have in the connection queue.
-	// 0 is normal, 1 is high
-	int m_priority;
-
 	// used for DNS lookups
 	resolver_flags m_resolve_flags;
 
@@ -231,20 +239,23 @@ private:
 	bool m_bottled;
 
 	// set to true the first time the handler is called
-	bool m_called;
+	bool m_called = false;
 
 	// only hand out new quota 4 times a second if the
 	// quota is 0. If it isn't 0 wait for it to reach
 	// 0 and continue to hand out quota at that time.
-	bool m_limiter_timer_active;
+	bool m_limiter_timer_active = false;
 
 	// true if the connection is using ssl
-	bool m_ssl;
+	bool m_ssl = false;
 
-	bool m_abort;
+	bool m_abort = false;
 
 	// true while waiting for an async_connect
-	bool m_connecting;
+	bool m_connecting = false;
+
+	// true while resolving hostname
+	bool m_resolving_host = false;
 };
 
 }
