@@ -607,19 +607,16 @@ namespace aux {
 			// will go straight to download mode.
 			no_recheck_incomplete_resume,
 
-			// ``anonymous_mode``: When set to true, the client
-			// tries to hide its identity to a certain degree. The user-agent will be
-			// reset to an empty string (except for private torrents). Trackers
-			// will only be used if they are using a proxy server.
-			// The listen sockets are closed, and incoming
-			// connections will only be accepted through a SOCKS5 or I2P proxy (if
-			// a peer proxy is set up and is run on the same machine as the
-			// tracker proxy). Since no incoming connections are accepted,
-			// NAT-PMP, UPnP, DHT and local peer discovery are all turned off when
-			// this setting is enabled.
+			// ``anonymous_mode``: When set to true, the client tries to hide
+			// its identity to a certain degree.
 			//
-			// If you're using I2P, it might make sense to enable anonymous mode
-			// as well.
+			// * A generic user-agent will be
+			//   used for trackers (except for private torrents).
+			// * Your local IPv4 and IPv6 address won't be sent as query string
+			//   parameters to private trackers.
+			// * If announce_ip is configured, it will not be sent to trackers
+			// * The client version will not be sent to peers in the extension
+			//   handshake.
 			anonymous_mode,
 
 			// specifies whether downloads from web seeds is reported to the
@@ -1150,13 +1147,17 @@ namespace aux {
 			outgoing_port,
 			num_outgoing_ports,
 
-			// ``peer_tos`` determines the TOS byte set in the IP header of every
+			// ``peer_dscp`` determines the DSCP field in the IP header of every
 			// packet sent to peers (including web seeds). ``0x0`` means no marking,
-			// ``0x20`` represents the *QBone scavenger service*. For more
-			// details, see QBSS_.
+			// ``0x04`` represents Lower Effort. For more details see `RFC 8622`_.
 			//
-			// .. _`QBSS`: http://qbone.internet2.edu/qbss/
-			peer_tos,
+			// .. _`RFC 8622`: http://www.faqs.org/rfcs/rfc8622.html
+			//
+			// ``peer_tos`` is the backwards compatible name for this setting.
+			peer_dscp,
+
+			// hidden
+			peer_tos = peer_dscp,
 
 			// for auto managed torrents, these are the limits they are subject
 			// to. If there are too many torrents some of the auto managed ones
